@@ -33,7 +33,7 @@ import matplotlib.cm
 import numpy as np
 from osgeo import ogr
 from .filesystem import juststem, justfname, forceext, justext
-from gdal2numpy import GDAL2Numpy, GetMetaData, GetSpatialRef, GetExtent, GetMinMax, GetTag
+from gdal2numpy import GDAL2Numpy, GetMetaData, GetSpatialRef, GetExtent, GetMinMax
 
 def GetGeomTypeName(filename):
     """
@@ -116,6 +116,9 @@ def create_qlr(filename, fileqlr="", cmapname=None):
 
         # Redefine sand, silt, clay cmap
         if ext == "tif":
+            # assert that "type" is a valid key
+            if not "type" in metadata:
+                metadata["type"] = "raster"
 
             cmapname = cmapname if cmapname else metadata["type"]
 
@@ -163,6 +166,10 @@ def create_qlr(filename, fileqlr="", cmapname=None):
         # Vector
         elif ext == "shp":
 
+            # assert that "type" is a valid key
+            if not "type" in metadata:
+                metadata["type"] = "Polygon"
+
             cmapname = cmapname if cmapname else metadata["type"]
             geomtype = GetGeomTypeName(filename)
             filetpl = pkg_resources.resource_filename(__name__, f"data/{geomtype}.qlr")
